@@ -1,7 +1,7 @@
 #
 # This file is part of App-SpreadRevolutionaryDate
 #
-# This software is Copyright (c) 2019-2023 by Gérald Sédrati.
+# This software is Copyright (c) 2019-2024 by Gérald Sédrati.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::Target::Twitter;
-$App::SpreadRevolutionaryDate::Target::Twitter::VERSION = '0.33';
+$App::SpreadRevolutionaryDate::Target::Twitter::VERSION = '0.34';
 # ABSTRACT: Target class for L<App::SpreadRevolutionaryDate> to handle spreading on Twitter.
 
 use Moose;
@@ -87,7 +87,7 @@ sub spread {
 
     $io->say($msg);
   } else {
-    $self->obj->post('https://api.twitter.com/2/tweets', {'-to_json' => {"text" => $msg}});
+    $self->obj->post('tweets', {'-to_json' => {"text" => $msg}});
   }
 }
 
@@ -114,7 +114,7 @@ App::SpreadRevolutionaryDate::Target::Twitter - Target class for L<App::SpreadRe
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 METHODS
 
@@ -136,8 +136,12 @@ Spreads a message to Twitter. Takes one mandatory argument: C<$msg> which should
 
 =item L<App::SpreadRevolutionaryDate::Config>
 
+=item L<App::SpreadRevolutionaryDate::BlueskyLite>
+
 =item L<App::SpreadRevolutionaryDate::Target>
 
+=item L<App::SpreadRevolutionaryDate::Target::Bluesky>
+
 =item L<App::SpreadRevolutionaryDate::Target::Mastodon>
 
 =item L<App::SpreadRevolutionaryDate::Target::Freenode>
@@ -174,7 +178,7 @@ Gérald Sédrati <gibus@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019-2023 by Gérald Sédrati.
+This software is Copyright (c) 2019-2024 by Gérald Sédrati.
 
 This is free software, licensed under:
 
